@@ -40,6 +40,7 @@ from ._admin import (
     _OrgUserWithInfo,
     _Quota,
     _Storage,
+    _StorageInstance,
     _UserInfo,
 )
 from ._bucket_base import (
@@ -81,6 +82,7 @@ from ._jobs import (
     Container,
     HTTPPort,
     JobDescription,
+    JobPriority,
     JobRestartPolicy,
     Jobs,
     JobStatus,
@@ -109,7 +111,7 @@ from ._url_utils import CLUSTER_SCHEMES as SCHEMES
 from ._users import Action, Permission, Quota, Share, Users
 from ._utils import _ContextManager, find_project_root
 
-__version__ = "22.1.0"
+__version__ = "22.6.0"
 
 
 __all__ = (
@@ -159,6 +161,7 @@ __all__ = (
     "ImageProgressStep",
     "Images",
     "JobDescription",
+    "JobPriority",
     "JobRestartPolicy",
     "JobStatus",
     "JobStatusHistory",
@@ -218,6 +221,7 @@ __all__ = (
     "_OrgUserWithInfo",
     "_Quota",
     "_Storage",
+    "_StorageInstance",
     "_UserInfo",
     "__version__",
     "find_project_root",
