@@ -199,12 +199,17 @@ class Config(metaclass=NoPublicConstructor):
             raise RuntimeError(
                 f"Cluster {name} doesn't exist in "
                 f"a list of available clusters {list(self.clusters)}. "
-                f"Please logout and login again."
             )
+        cluster_orgs = self.clusters[name].orgs
         org_name = self.org_name
-        if org_name not in self.clusters[name].orgs:
-            # Cannot keep using same org, set to first available
-            org_name = self.clusters[name].orgs[0]
+        if org_name not in cluster_orgs:
+            # Cannot keep using same org
+            # If NO_ORG is available - use it
+            # else use first in alphabetical order
+            if None in cluster_orgs:
+                org_name = None
+            else:
+                org_name = sorted(cluster_orgs, key=lambda it: it or "")[0]
         self.__config_data = replace(
             self._config_data, cluster_name=name, org_name=org_name
         )
@@ -221,7 +226,6 @@ class Config(metaclass=NoPublicConstructor):
                 f"Org {name or 'NO_ORG'} doesn't exist in "
                 f"a list of available orgs {list(cluster_org_names)} for "
                 f"cluster '{self.cluster_name}'. "
-                f"Please logout and login again."
             )
         self.__config_data = replace(self._config_data, org_name=name)
         _save(self._config_data, self._path)
