@@ -16,6 +16,7 @@ from typing import (
     Optional,
     Sequence,
     Set,
+    Union,
     overload,
 )
 
@@ -37,7 +38,7 @@ from ._abc import (
 )
 from ._config import Config
 from ._core import _Core
-from ._errors import NDJSONError, ResourceNotFound, StdStreamError
+from ._errors import NDJSONError, StdStreamError
 from ._images import (
     _DummyProgress,
     _raise_on_error_chunk,
@@ -51,7 +52,12 @@ from ._url_utils import (
     normalize_secret_uri,
     normalize_storage_path_uri,
 )
-from ._utils import NoPublicConstructor, asyncgeneratorcontextmanager
+from ._utils import (
+    ORG_NAME_SENTINEL,
+    NoPublicConstructor,
+    OrgNameSentinel,
+    asyncgeneratorcontextmanager,
+)
 
 log = logging.getLogger(__package__)
 
@@ -199,6 +205,13 @@ class JobRestartPolicy(str, enum.Enum):
         return repr(self.value)
 
 
+@rewrite_module
+class JobPriority(enum.IntEnum):
+    LOW = enum.auto()
+    NORMAL = enum.auto()
+    HIGH = enum.auto()
+
+
 @rewrite_module
 @dataclass(frozen=True)
 class JobDescriptionInternal:
@@ -234,6 +247,7 @@ class JobDescription:
     org_name: Optional[str] = None
     preemptible_node: bool = False
     privileged: bool = False
+    priority: JobPriority = JobPriority.NORMAL
     _internal: JobDescriptionInternal = JobDescriptionInternal()
 
 
@@ -317,7 +331,8 @@ class Jobs(metaclass=NoPublicConstructor):
         schedule_timeout: Optional[float] = None,
         restart_policy: JobRestartPolicy = JobRestartPolicy.NEVER,
         life_span: Optional[float] = None,
-        org_name: Optional[str] = None,
+        org_name: Union[Optional[str], OrgNameSentinel] = ORG_NAME_SENTINEL,
+        priority: Optional[JobPriority] = None,
     ) -> JobDescription:
         url = self._config.api_url / "jobs"
         payload = _job_to_api(
@@ -330,7 +345,10 @@ class Jobs(metaclass=NoPublicConstructor):
             schedule_timeout=schedule_timeout,
             restart_policy=restart_policy,
             life_span=life_span,
-            org_name=org_name,
+            org_name=org_name
+            if not isinstance(org_name, OrgNameSentinel)
+            else self._config.org_name,
+            priority=priority,
         )
         payload["container"] = _container_to_api(
             config=self._config,
@@ -359,7 +377,7 @@ class Jobs(metaclass=NoPublicConstructor):
         image: RemoteImage,
         preset_name: str,
         cluster_name: Optional[str] = None,
-        org_name: Optional[str] = None,
+        org_name: Union[Optional[str], OrgNameSentinel] = ORG_NAME_SENTINEL,
         entrypoint: Optional[str] = None,
         command: Optional[str] = None,
         working_dir: Optional[str] = None,
@@ -380,6 +398,7 @@ class Jobs(metaclass=NoPublicConstructor):
         restart_policy: JobRestartPolicy = JobRestartPolicy.NEVER,
         life_span: Optional[float] = None,
         privileged: bool = False,
+        priority: Optional[JobPriority] = None,
     ) -> JobDescription:
         url = (self._config.api_url / "jobs").with_query("from_preset")
         container_payload = _container_to_api(
@@ -409,7 +428,10 @@ class Jobs(metaclass=NoPublicConstructor):
             restart_policy=restart_policy,
             life_span=life_span,
             privileged=privileged,
-            org_name=org_name,
+            org_name=org_name
+            if not isinstance(org_name, OrgNameSentinel)
+            else self._config.org_name,
+            priority=priority,
         )
         payload.update(**container_payload)
         auth = await self._config._api_auth()
@@ -510,7 +532,7 @@ class Jobs(metaclass=NoPublicConstructor):
         separator: Optional[str] = None,
         debug: bool = False,
     ) -> AsyncIterator[bytes]:
-        url = self._get_monitoring_url(cluster_name) / id / "log"
+        url = self._get_monitoring_url(cluster_name) / id / "log_ws"
         if since is not None:
             if since.tzinfo is None:
                 # Interpret naive datetime object as local time.
@@ -522,17 +544,16 @@ class Jobs(metaclass=NoPublicConstructor):
             url = url.update_query(separator=separator)
         if debug:
             url = url.update_query(debug="true")
-        timeout = attr.evolve(self._core.timeout, sock_read=None)
         auth = await self._config._api_auth()
-        async with self._core.request(
-            "GET",
+        async with self._core.ws_connect(
             url,
-            headers={"Accept-Encoding": "identity"},
-            timeout=timeout,
             auth=auth,
-        ) as resp:
-            async for data in resp.content.iter_any():
-                yield data
+            timeout=None,
+            heartbeat=30,
+        ) as ws:
+            async for msg in ws:
+                if msg.data:
+                    yield msg.data
 
     async def status(self, id: str) -> JobDescription:
         url = self._config.api_url / "jobs" / id
@@ -550,9 +571,10 @@ class Jobs(metaclass=NoPublicConstructor):
         try:
             received_any = False
             async with self._core.ws_connect(url, auth=auth) as ws:
-                async for resp in ws:
-                    yield _job_telemetry_from_api(resp.json())
-                    received_any = True
+                async for msg in ws:
+                    if msg.type == aiohttp.WSMsgType.TEXT:
+                        yield _job_telemetry_from_api(msg.json())
+                        received_any = True
             if not received_any:
                 raise ValueError(f"Job is not running. Job Id = {id}")
         except WSServerHandshakeError as e:
@@ -639,35 +661,28 @@ class Jobs(metaclass=NoPublicConstructor):
             loop = asyncio.get_event_loop()
             url = self._get_monitoring_url(cluster_name)
             url = url / id / "port_forward" / str(job_port)
-            auth = await self._config._api_auth()
-            ws = await self._core._session.ws_connect(
+            async with self._core.ws_connect(
                 url,
-                headers={"Authorization": auth},
-                timeout=None,  # type: ignore
+                auth=await self._config._api_auth(),
+                timeout=None,
                 receive_timeout=None,
                 heartbeat=30,
-            )
-            tasks = []
-            tasks.append(loop.create_task(self._port_reader(ws, writer)))
-            tasks.append(loop.create_task(self._port_writer(ws, reader)))
-            try:
-                await asyncio.wait(tasks, return_when=asyncio.FIRST_COMPLETED)
-            finally:
-                for task in tasks:
-                    if not task.done():
-                        task.cancel()
-                        with suppress(asyncio.CancelledError):
-                            await task
-                writer.close()
-                await writer.wait_closed()
-                await ws.close()
+            ) as ws:
+                tasks = []
+                tasks.append(loop.create_task(self._port_reader(ws, writer)))
+                tasks.append(loop.create_task(self._port_writer(ws, reader)))
+                try:
+                    await asyncio.wait(tasks, return_when=asyncio.FIRST_COMPLETED)
+                finally:
+                    for task in tasks:
+                        if not task.done():
+                            task.cancel()
+                            with suppress(asyncio.CancelledError):
+                                await task
+                    writer.close()
+                    await writer.wait_closed()
         except asyncio.CancelledError:
             raise
-        except WSServerHandshakeError as e:
-            if e.headers and "X-Error" in e.headers:
-                log.error(f"Error during port-forwarding: {e.headers['X-Error']}")
-            log.exception("Unhandled exception during port-forwarding")
-            writer.close()
         except Exception:
             log.exception("Unhandled exception during port-forwarding")
             writer.close()
@@ -712,26 +727,17 @@ class Jobs(metaclass=NoPublicConstructor):
         )
         auth = await self._config._api_auth()
 
-        try:
-            ws = await self._core._session.ws_connect(
-                url,
-                headers={
-                    "Authorization": auth,
-                    aiohttp.hdrs.SEC_WEBSOCKET_PROTOCOL: "v2.channels.neu.ro",
-                },
-                timeout=None,  # type: ignore
-                receive_timeout=None,
-                heartbeat=30,
-            )
-        except aiohttp.ClientResponseError as ex:
-            if ex.status == 404:
-                raise ResourceNotFound(f"Job {id!r} is not running")
-            raise
-
-        try:
+        async with self._core.ws_connect(
+            url,
+            auth=auth,
+            headers={
+                aiohttp.hdrs.SEC_WEBSOCKET_PROTOCOL: "v2.channels.neu.ro",
+            },
+            timeout=None,
+            receive_timeout=None,
+            heartbeat=30,
+        ) as ws:
             yield StdStream(ws)
-        finally:
-            await ws.close()
 
     @asynccontextmanager
     async def exec(
@@ -755,23 +761,17 @@ class Jobs(metaclass=NoPublicConstructor):
         )
         auth = await self._config._api_auth()
 
-        try:
-            ws = await self._core._session.ws_connect(
-                url,
-                headers={"Authorization": auth},
-                timeout=None,  # type: ignore
-                receive_timeout=None,
-                heartbeat=30,
-            )
-        except aiohttp.ClientResponseError as ex:
-            if ex.status == 404:
-                raise ResourceNotFound(f"Job {id!r} is not running")
-            raise
-
-        try:
-            yield StdStream(ws)
-        finally:
-            await ws.close()
+        async with self._core.ws_connect(
+            url,
+            auth=auth,
+            timeout=None,
+            receive_timeout=None,
+            heartbeat=30,
+        ) as ws:
+            try:
+                yield StdStream(ws)
+            finally:
+                await ws.close()
 
     async def send_signal(self, id: str, *, cluster_name: Optional[str] = None) -> None:
         url = self._get_monitoring_url(cluster_name) / id / "kill"
@@ -1002,6 +1002,7 @@ def _job_description_from_api(res: Dict[str, Any], parse: Parser) -> JobDescript
     # https://github.com/neuro-inc/platform-api/pull/1770 merged
     total_price_credits = Decimal(res["total_price_credits"])
     price_credits_per_hour = Decimal(res["price_credits_per_hour"])
+    priority = JobPriority[res.get("priority", JobPriority.NORMAL.name).upper()]
     return JobDescription(
         status=_calc_status(res["status"]),
         id=res["id"],
@@ -1026,6 +1027,7 @@ def _job_description_from_api(res: Dict[str, Any], parse: Parser) -> JobDescript
         preset_name=res.get("preset_name"),
         total_price_credits=total_price_credits,
         price_credits_per_hour=price_credits_per_hour,
+        priority=priority,
         _internal=JobDescriptionInternal(
             materialized=res.get("materialized", False),
             being_dropped=res.get("being_dropped", False),
@@ -1047,6 +1049,7 @@ def _job_to_api(
     life_span: Optional[float] = None,
     privileged: bool = False,
     org_name: Optional[str] = None,
+    priority: Optional[JobPriority] = None,
 ) -> Dict[str, Any]:
     primitive: Dict[str, Any] = {"pass_config": pass_config}
     if name:
@@ -1069,6 +1072,8 @@ def _job_to_api(
         primitive["privileged"] = privileged
     if org_name:
         primitive["org_name"] = org_name
+    if priority:
+        primitive["priority"] = priority.name.lower()
     primitive["cluster_name"] = cluster_name
     return primitive
 
