@@ -1,11 +1,9 @@
-import asyncio
 from dataclasses import replace
 from decimal import Decimal
 from pathlib import Path
 from typing import Any, Callable, Dict, Optional
 
 import aiohttp
-import aiohttp.pytest_plugin
 import pytest
 from jose import jwt
 from yarl import URL
@@ -15,15 +13,6 @@ from neuro_sdk._config import _AuthConfig, _AuthToken, _ConfigData, _save
 from neuro_sdk._tracing import _make_trace_config
 
 
-def setup_test_loop(
-    loop_factory: Callable[[], asyncio.AbstractEventLoop] = asyncio.new_event_loop
-) -> asyncio.AbstractEventLoop:
-    return loop_factory()
-
-
-aiohttp.pytest_plugin.setup_test_loop = setup_test_loop
-
-
 @pytest.fixture
 def token() -> str:
     return jwt.encode({"identity": "user"}, "secret", algorithm="HS256")
@@ -103,6 +92,7 @@ def make_client(
         clusters: Optional[Dict[str, Cluster]] = None,
         token_url: Optional[URL] = None,
         plugin_manager: Optional[PluginManager] = None,
+        org_name: Optional[str] = None,
         **kwargs: Any,
     ) -> Client:
         url = URL(url_str)
@@ -138,7 +128,7 @@ def make_client(
                     ),
                 },
                 name="default",
-                orgs=[None],
+                orgs=[org_name],
             )
             cluster2_config = Cluster(
                 registry_url=(url / "registry2"),
